@@ -1917,6 +1917,7 @@ static int vimos_science(cpl_parameterlist *parlist, cpl_frameset *frameset,
                                 &contrib) != CPL_ERROR_NONE)
         {   
             cpl_msg_error(recipe, "Cannot stack science images");
+            cpl_image_delete(sky_stacked);
             return -1;
         }
         cpl_image_delete(contrib);
@@ -2171,11 +2172,11 @@ static int vimos_science(cpl_parameterlist *parlist, cpl_frameset *frameset,
         //TODO: Place this in a better place. The whole recipe needs refactoring...
         cpl_image        * mapped_flat_sed = NULL;
         cpl_propertylist * flat_sed_header = NULL;
+        vimos::detected_slits det_slits = 
+                vimos::detected_slits_from_tables(slits, polytraces, nx);
+        mosca::wavelength_calibration wave_cal(idscoeff, refwave);
         if(photcal_apply_flat_corr)
         {
-            vimos::detected_slits det_slits = 
-                    vimos::detected_slits_from_tables(slits, polytraces, nx);
-            mosca::wavelength_calibration wave_cal(idscoeff, refwave);
             const cpl_frame * flat_sed_frame = 
                     cpl_frameset_find_const(frameset, flat_sed_tag);
             const char * filename = cpl_frame_get_filename(flat_sed_frame);
@@ -2209,8 +2210,12 @@ static int vimos_science(cpl_parameterlist *parlist, cpl_frameset *frameset,
             if(photcal_apply_flat_corr)
             {
                 cpl_msg_info(cpl_func, "Applying flat SED correction");
-                vimos_science_correct_flat_sed_mapped(mapped_images, slits,
-                        mapped_flat_sed, flat_sed_header, specphot_header);
+                if(vimos_science_correct_flat_sed_mapped(mapped_images, slits,
+                        mapped_flat_sed, flat_sed_header, specphot_header,
+                        det_slits))
+                {
+                    return -1;
+                }
             }
 
             calibrated = mos_apply_photometry(mapped_images, response_interp,
@@ -2305,7 +2310,8 @@ static int vimos_science(cpl_parameterlist *parlist, cpl_frameset *frameset,
                 {
                     cpl_msg_info(cpl_func, "Applying flat SED correction");
                     vimos_science_correct_flat_sed(science_images, slits, 
-                            mapped_flat_sed, flat_sed_header, specphot_header);
+                            mapped_flat_sed, flat_sed_header, specphot_header,
+                            det_slits);
                 }
                 
                 calibrated = mos_apply_photometry(science_images, response_interp,
@@ -2386,9 +2392,11 @@ static int vimos_science(cpl_parameterlist *parlist, cpl_frameset *frameset,
                 {
                     //We assume that the mapped flat profile has no associated error
                     vimos_science_correct_flat_sed(science_images, slits, 
-                            mapped_flat_sed, flat_sed_header, specphot_header);
+                            mapped_flat_sed, flat_sed_header, specphot_header,
+                            det_slits);
                     vimos_science_correct_flat_sed(science_images_err, slits, 
-                            mapped_flat_sed, flat_sed_header, specphot_header);
+                            mapped_flat_sed, flat_sed_header, specphot_header,
+                            det_slits);
                 }
 
                 calibrated = mos_propagate_photometry_error(science_images, 
